package de.mlessmann.certassist;

import static org.assertj.core.api.Assertions.assertThat;

import de.mlessmann.certassist.openssl.CertificateRequest;
import de.mlessmann.certassist.openssl.CertificateRequestExtension;
import de.mlessmann.certassist.openssl.CertificateSubject;
import de.mlessmann.certassist.service.CertificateCreationService;
import java.nio.file.Path;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

@SpringBootTest
public class CertificateServiceTest {

    @Autowired
    private CertificateCreationService certificateService;

    @Test
    void testCanCreateCertificate() {
        var request = CertificateRequest
            .builder()
            .type(CertificateRequest.RequestType.STANDALONE_CERTIFICATE)
            .subject(
                CertificateSubject
                    .builder()
                    .commonName("cert.creation")
                    .country("DE")
                    .state("SH")
                    .locality("HH")
                    .organization("Crazy-Cats")
            )
            .extension(CertificateRequestExtension.builder().alternativeNames("test2.home", "test3.home"))
            .build();
        var cert = certificateService.createCertificate(request);
        assertThat(cert).isNotNull();
        assertThat(cert.getId()).isGreaterThan("0");
    }

    @Test
    void testCanImportCertificate() {
        Path certDir = TestOpenSSLCertificateCreator.TEST_CERT_PATH;
        var importedCert = certificateService.importCertificate(
            certDir.resolve("x509forImport.pem"),
            certDir.resolve("x509forImport.key.pem"),
            TestOpenSSLCertificateCreator.TEST_CERT_PASSPHRASE
        );
        assertThat(importedCert).isNotNull();
        assertThat(importedCert.getId()).isGreaterThan("0");
    }
}
